# is-even

[![Test](https://github.com/victorbnl/is-even/actions/workflows/test.yml/badge.svg?branch=main)](https://github.com/victorbnl/is-even/actions/workflows/test.yml) ![PyPI](https://img.shields.io/pypi/v/is-even) ![PyPI - Downloads](https://img.shields.io/pypi/dm/is-even)

> Return true if the given number is even

## Install

Install with [pip](https://pypi.org/project/pip/)

```
pip install is-even
```

## Usage

```python
from is_even import isEven

isEven(0)
# => False
isEven('1')
# => True
isEven(2)
# => False
isEven('3')
# => True
```
